@@ -3,7 +3,10 @@ from django.utils.html import format_html
 from django_common_objects.admin import UserAdmin
 from django.db.models import Count
 from .choices import TaskScheduleType, ScheduleTimingType
-from . import models, forms
+from . import models, forms, get_task_model, get_schedule_log_model
+
+TaskModel = get_task_model()
+TaskScheduleLogModel = get_schedule_log_model()
 
 
 class TaskAdmin(UserAdmin):
@@ -74,7 +77,7 @@ class TaskScheduleAdmin(UserAdmin):
     fields = (
         ("task", "status"),
         "nlp_sentence",
-        ("schedule_type", 'priority'),
+        ("schedule_type", 'priority', 'base_on_now'),
         "period_schedule",
         "once_schedule",
         "crontab",
@@ -147,13 +150,13 @@ class TaskScheduleAdmin(UserAdmin):
 
 
 class TaskScheduleLogAdmin(UserAdmin):
-    list_display = ('id', 'schedule', 'schedule_time', 'finish_time')
+    list_display = ('id', 'schedule', 'status', 'schedule_time', 'create_time')
 
     def get_readonly_fields(self, request, obj=None):
         return [field.name for field in self.model._meta.fields]
 
 
-admin.site.register(models.Task, TaskAdmin)
+admin.site.register(TaskModel, TaskAdmin)
 admin.site.register(models.TaskSchedule, TaskScheduleAdmin)
 admin.site.register(models.TaskScheduleCallback, TaskScheduleCallbackAdmin)
-admin.site.register(models.TaskScheduleLog, TaskScheduleLogAdmin)
+admin.site.register(TaskScheduleLogModel, TaskScheduleLogAdmin)
